@@ -34,7 +34,7 @@
 
 
 
-function windows_read_do () {
+function windows_read_do ($args) {
 
       global $data_dir, $username, $mailbox, $msg, 
              $startMsg, $searchString, $javascript_on;
@@ -42,6 +42,8 @@ function windows_read_do () {
 
       if (getPref($data_dir, $username, 'windows_on_read', 0) == 1) {
 
+         $startMsg = $args[0];
+         $searchString = $args[1];
          $urlMailbox = urlencode($mailbox);
          $read_new_win_height = getPref($data_dir, $username, 'read_new_win_height', 0);
          $read_new_win_width = getPref($data_dir, $username, 'read_new_win_width', 0);
