@@ -1,7 +1,8 @@
 <?php
    /*
-    *  Windows Plugin v.1.4
+    *  Windows Plugin v.1.5
     *  By Shawn South <shawn@ratbert.org>
+    *  Updated by Paul Lesneiwski <pdontthink@angrynerds.com>
     *  (c) 2000 (GNU GPL - see ../../COPYING)
     *
     *  This plugin opens a fresh browser window when you click on a message,
@@ -44,14 +45,14 @@ function squirrelmail_plugin_init_windows() {
 }
 
 
-function windows_read () {
+function windows_read ($args) {
 
   if (defined('SM_PATH'))
      include_once(SM_PATH . 'plugins/windows/functions.php');
   else
      include_once('../plugins/windows/functions.php');
 
-  return windows_read_do();
+  return windows_read_do($args);
 
 }
 
@@ -93,7 +94,7 @@ function windows_save_prefs () {
 
 function windows_version () {
 
-   return '1.4';
+   return '1.5';
 
 }
 
